import { ComponentResource, ComponentResourceOptions } from "@pulumi/pulumi";
import { Vpc, InternetGateway, RouteTable } from "@pulumi/aws/ec2";
import { SubnetGroup as RdsSubnetGroup } from "@pulumi/aws/rds";
import { SubnetGroup as EcSubnetGroup } from "@pulumi/aws/elasticache";
import { VpcDns } from "./VpcDns";
import { VpcSubnetGroup } from "./VpcSubnetGroup";
import { VpcNat } from "./VpcNat";
/**
 * DNS configuration options for a `VpcNetwork`
 */
export interface VpcNetworkDnsOptions {
    domain: string;
    nameServers?: string[];
    region?: string;
}
/**
 * Configuration options for a `VpcNetwork`
 */
export interface VpcNetworkOptions {
    cidrBlock: string;
    dnsOptions?: VpcNetworkDnsOptions;
    maxZones?: number;
    name: string;
    subnetOptions?: VpcNetworkSubnetOptions;
}
export interface VpcNetworkSubnetOptions {
    azAdditionalBits?: number;
    subnetAdditionalBits?: number[];
}
/**
 * A `VpcNetwork` provides multiple resources to establish a consistent baseline for logical
 * networking organization.
 */
export declare class VpcNetwork extends ComponentResource {
    /**
     * The `VPC`
     */
    readonly vpc: Vpc;
    /**
     * An `InternetGateway` for external communication
     */
    readonly gateway: InternetGateway;
    /**
     * A `RouteTable` for public facing resources
     */
    readonly externalRoutes: RouteTable;
    /**
     * `RouteTables` for internal resources
     */
    readonly internalRoutes: RouteTable[];
    /**
     * (optional) DNS resources
     */
    readonly dns?: VpcDns;
    /**
     * `NatInstances` and their associated `RouteTables`
     * @see internalRoutes
     */
    readonly nats: VpcNat[];
    /**
     * Subnets for externally facing resources
     */
    readonly externalSubnets: VpcSubnetGroup;
    /**
     * Subnets used for internal, or private, resources only
     */
    readonly internalSubnets: VpcSubnetGroup;
    /**
     * Subnets for data resources, like caches and databases
     */
    readonly dataSubnets: VpcSubnetGroup;
    /**
     * Subnets for networking resources, such as domain controllers
     */
    readonly networkSubnets: VpcSubnetGroup;
    /**
     * Default `SubnetGroup` for RDS
     */
    readonly rdsSubnetGroup: RdsSubnetGroup;
    /**
     * Default `SubnetGroup` for ElastiCache
     */
    readonly ecSubnetGroup: EcSubnetGroup;
    protected namePrefix: string;
    constructor(name: string, options: VpcNetworkOptions, extra?: ComponentResourceOptions);
}
