import { ComponentResource, ComponentResourceOptions, Input } from "@pulumi/pulumi";
import { VpcSubnet, VpcSubnetType } from "./VpcSubnet";
import { RouteTable } from "@pulumi/aws/ec2";
import { VpcSubnetCidrBlock } from "./VpcCidr";
/**
 * Configuration options for the VpcSubnetGroup component
 */
export interface VpcSubnetGroupOptions {
    namePrefix: string;
    routeTables: RouteTable[];
    subnetCidrBlocks: VpcSubnetCidrBlock[];
    type: VpcSubnetType;
    vpcId: string | Input<string>;
}
/**
 * A VpcSubnetGroup is a collection of subnets across multiple AZs that share a common purpose,
 * such as for data resources like caches or databases.  They'll have similar CIDRs, incremented
 * by the defined `blockSize`.
 */
export declare class VpcSubnetGroup extends ComponentResource {
    readonly subnets: VpcSubnet[];
    readonly type: VpcSubnetType;
    constructor(name: string, options: VpcSubnetGroupOptions, extra?: ComponentResourceOptions);
}
