"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pulumi_1 = require("@pulumi/pulumi");
const VpcSubnet_1 = require("./VpcSubnet");
/**
 * A VpcSubnetGroup is a collection of subnets across multiple AZs that share a common purpose,
 * such as for data resources like caches or databases.  They'll have similar CIDRs, incremented
 * by the defined `blockSize`.
 */
class VpcSubnetGroup extends pulumi_1.ComponentResource {
    constructor(name, options, extra) {
        super('sophosoft:aws:VpcSubnetGroup', name, {}, extra);
        this.subnets = [];
        this.type = options.type;
        options.subnetCidrBlocks.map((block, index) => {
            let table = options.routeTables[index] || options.routeTables[0];
            this.subnets.push(new VpcSubnet_1.VpcSubnet(`${name}-${index + 1}`, {
                availabilityZone: block.zone,
                cidrBlock: block.cidr,
                routeTableId: table.id,
                type: this.type,
                vpcId: options.vpcId,
                namePrefix: options.namePrefix
            }, Object.assign(Object.assign({}, extra), { parent: this })));
        });
        this.registerOutputs({
            subnets: this.subnets,
            type: this.type
        });
    }
}
exports.VpcSubnetGroup = VpcSubnetGroup;
